@@ -2,7 +2,8 @@
 library("SPUTNIK")
 
 ## Mass spectrometry intensity matrix
-X <- matrix(rnorm(200), 20, 40)
+X <- matrix(rnorm(16000), 400, 40)
+X[X < 0] <- 0
 
 ## Print original dimensions
 print(dim(X))
@@ -11,7 +12,7 @@ print(dim(X))
 mzVector <- seq(600, 900, by = (900 - 600) / 39)
 
 ## Read the image size
-imSize <- c(5, 4)
+imSize <- c(20, 20)
 
 ## Construct the ms.dataset object
 msiX <- msiDataset(X, mzVector, imSize[1], imSize[2])
@@ -20,8 +21,10 @@ msiX <- msiDataset(X, mzVector, imSize[1], imSize[2])
 ref.roi <- refAndROIimages(msiX, refMethod = "sum", roiMethod = "otsu")
 
 ## Perform global peaks filter
-glob.peaks <- globalPeaksFilter(msiData = msiX, referenceImage = ref.roi$Reference,
-                                method = "pearson", threshold = 0)
+glob.peaks <- globalPeaksFilter(
+  msiData = msiX, referenceImage = ref.roi$Reference,
+  method = "pearson", threshold = 0
+)
 
 ## Apply the filter
 msiX <- applyPeaksFilter(msiX, glob.peaks)
